==> jdk-22.0.2_windows-x64_bin.zip: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_af.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_af extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "CAD", "CAD" },
            { "MXN", "MXN" },
            { "PHP", "PHP" },
            { "THB", "\u0e3f" },
            { "USD", "USD" },
            { "ZAR", "R" },
            { "aed", "Verenigde Arabiese Emirate-dirham" },
            { "afn", "Afgaanse afgani" },
            { "all", "Albanese lek" },
            { "amd", "Armeense dram" },
            { "ang", "Nederlands-Antilliaanse gulde" },
            { "aoa", "Angolese kwanza" },
            { "ars", "Argentynse peso" },
            { "aud", "Australiese dollar" },
            { "awg", "Arubaanse floryn" },
            { "azn", "Azerbeidjaanse manat" },
            { "bam", "Bosnies-Herzegowiniese omskakelbare marka" },
            { "bbd", "Barbados-dollar" },
            { "bdt", "Bangladesjiese taka" },
            { "bgn", "Bulgaarse lev" },
            { "bhd", "Bahreinse dinar" },
            { "bif", "Burundiese frank" },
            { "bmd", "Bermuda-dollar" },
            { "bnd", "Broeneise dollar" },
            { "bob", "Boliviaanse boliviano" },
            { "brl", "Brasilliaanse reaal" },
            { "bsd", "Bahamiaanse dollar" },
            { "btn", "Bhoetanese ngoeltroem" },
            { "bwp", "Botswana-pula" },
            { "byn", "Belarusiese roebel" },
            { "byr", "Belo-Russiese roebel (2000\u20132016)" },
            { "bzd", "Beliziese dollar" },
            { "cad", "Kanadese dollar" },
            { "cdf", "Kongolese frank" },
            { "chf", "Switserse frank" },
            { "clp", "Chileense peso" },
            { "cnh", "Chinese joean (buiteland)" },
            { "cny", "Chinese joean" },
            { "cop", "Colombiaanse peso" },
            { "crc", "Costa Ricaanse col\u00f3n" },
            { "cuc", "Kubaanse omskakelbare peso" },
            { "cup", "Kubaanse peso" },
            { "cve", "Kaap Verdiese escudo" },
            { "czk", "Tsjeggiese kroon" },
            { "djf", "Djiboeti-frank" },
            { "dkk", "Deense kroon" },
            { "dop", "Dominikaanse peso" },
            { "dzd", "Algeriese dinar" },
            { "egp", "Egiptiese pond" },
            { "ern", "Eritrese nakfa" },
            { "etb", "Etiopiese birr" },
            { "eur", "Euro" },
            { "fjd", "Fidjiaanse dollar" },
            { "fkp", "Falkland-eilandse pond" },
            { "gbp", "Britse pond" },
            { "gel", "Georgiese lari" },
            { "ghc", "Ghanese cedi (1979\u20132007)" },
            { "ghs", "Ghanese cedi" },
            { "gip", "Gibraltarese pond" },
            { "gmd", "Gambiese dalasi" },
            { "gnf", "Guinese frank" },
            { "gns", "Guinese syli" },
            { "gtq", "Guatemalaanse quetzal" },
            { "gyd", "Guyanese dollar" },
            { "hkd", "Hongkongse dollar" },
            { "hnl", "Hondurese lempira" },
            { "hrk", "Kroatiese kuna" },
            { "htg", "Ha\u00eftiaanse gourde" },
            { "huf", "Hongaarse florint" },
            { "idr", "Indonesiese roepia" },
            { "ils", "Israeliese nuwe sikkel" },
            { "inr", "Indiese roepee" },
            { "iqd", "Irakse dinar" },
            { "irr", "Iranse rial" },
            { "isk", "Yslandse kroon" },
            { "itl", "Italiaanse lier" },
            { "jmd", "Jamaikaanse dollar" },
            { "jod", "Jordaniese dinar" },
            { "jpy", "Japannese jen" },
            { "kes", "Keniaanse sjieling" },
            { "kgs", "Kirgisiese som" },
            { "khr", "Kambodjaanse riel" },
            { "kmf", "Comoraanse frank" },
            { "kpw", "Noord-Koreaanse won" },
            { "krw", "Suid-Koreaanse won" },
            { "kwd", "Koeweitse dinar" },
            { "kyd", "Cayman-eilandse dollar" },
            { "kzt", "Kazakse tenge" },
            { "lak", "Laosiaanse kip" },
            { "lbp", "Libanese pond" },
            { "lkr", "Sri Lankaanse roepee" },
            { "lrd", "Liberiese dollar" },
            { "lsl", "Lesotho loti" },
            { "ltl", "Litause litas" },
            { "lvl", "Lettiese lats" },
            { "lyd", "Libiese dinar" },
            { "mad", "Marokkaanse dirham" },
            { "mdl", "Moldowiese leu" },
            { "mga", "Malgassiese ariary" },
            { "mkd", "Macedoniese denar" },
            { "mmk", "Mianmese kyat" },
            { "mnt", "Mongoolse toegrik" },
            { "mop", "Macaose pataca" },
            { "mro", "Mauritaniese ouguiya (1973\u20132017)" },
            { "mru", "Mauritaniese ouguiya" },
            { "mur", "Mauritiaanse roepee" },
            { "mvr", "Malediviese rufia" },
            { "mwk", "Malawiese kwacha" },
            { "mxn", "Meksikaanse peso" },
            { "myr", "Maleisiese ringgit" },
            { "mzm", "Mosambiekse metical (1980\u20132006)" },
            { "mzn", "Mosambiekse metical" },
            { "nad", "Namibiese dollar" },
            { "ngn", "Nigeriese naira" },
            { "nio", "Nicaraguaanse c\u00f3rdoba" },
            { "nok", "Noorse kroon" },
            { "npr", "Nepalese roepee" },
            { "nzd", "Nieu-Seelandse dollar" },
            { "omr", "Omaanse rial" },
            { "pab", "Panamese balboa" },
            { "pen", "Peruaanse sol" },
            { "pgk", "Papoea-Nieu-Guinese kina" },
            { "php", "Filippynse peso" },
            { "pkr", "Pakistanse roepee" },
            { "pln", "Poolse zloty" },
            { "pyg", "Paraguaanse guarani" },
            { "qar", "Katarrese rial" },
            { "ron", "Roemeense leu" },
            { "rsd", "Serwiese dinar" },
            { "rub", "Russiese roebel" },
            { "rwf", "Rwandese frank" },
            { "sar", "Saoedi-Arabiese riyal" },
            { "sbd", "Salomonseilandse dollar" },
            { "scr", "Seychellese roepee" },
            { "sdg", "Soedannese pond" },
            { "sdp", "Soedannese pond (1957\u20131998)" },
            { "sek", "Sweedse kroon" },
            { "sgd", "Singapoer-dollar" },
            { "shp", "Sint Helena-pond" },
            { "sle", "Sierra Leoniese leone" },
            { "sll", "Sierra Leoniese leone (1964\u20142022)" },
            { "sos", "Somaliese sjieling" },
            { "srd", "Surinaamse dollar" },
            { "ssp", "Suid-Soedanese pond" },
            { "std", "S\u00e3o Tom\u00e9 en Pr\u00edncipe dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 en Pr\u00edncipe-dobra" },
            { "syp", "Siriese pond" },
            { "szl", "Swazilandse lilangeni" },
            { "thb", "Thaise baht" },
            { "tjs", "Tadjikse somoni" },
            { "tmt", "Turkmeense manat" },
            { "tnd", "Tunisiese dinar" },
            { "top", "Tongaanse pa\u2019anga" },
            { "trl", "Turkse lier (1922\u20132005)" },
            { "try", "Turkse lira" },
            { "ttd", "Trinidad en Tobago-dollar" },
            { "twd", "Nuwe Taiwanese dollar" },
            { "tzs", "Tanzaniese sjieling" },
            { "uah", "Oekra\u00efnse hriwna" },
            { "ugx", "Ugandese sjieling" },
            { "usd", "VSA-dollar" },
            { "uyu", "Uruguaanse peso" },
            { "uzs", "Oezbekiese som" },
            { "vef", "Venezolaanse bolivar" },
            { "ves", "Venezolaanse bol\u00edvar" },
            { "vnd", "Vi\u00ebtnamese dong" },
            { "vuv", "Vanuatuse vatu" },
            { "wst", "Samoaanse tala" },
            { "xaf", "Sentraal Afrikaanse CFA-frank" },
            { "xcd", "Oos-Karibiese dollar" },
            { "xof", "Wes-Afrikaanse CFA-frank" },
            { "xpf", "CFP-frank" },
            { "xxx", "Onbekende geldeenheid" },
            { "yer", "Jemenitiese rial" },
            { "zar", "Suid-Afrikaanse rand" },
            { "zmk", "Zambiese kwacha (1968\u20132012)" },
            { "zmw", "Zambiese kwacha" },
            { "zwd", "Zimbabwiese dollar" },
        };
        return data;
    }
}

==> jdk-24.0.1_windows-x64_bin.zip: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_af.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_af extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "CAD", "CAD" },
            { "MXN", "MXN" },
            { "PHP", "PHP" },
            { "THB", "\u0e3f" },
            { "USD", "USD" },
            { "ZAR", "R" },
            { "aed", "Verenigde Arabiese Emirate-dirham" },
            { "afn", "Afgaanse afgani" },
            { "all", "Albanese lek" },
            { "amd", "Armeense dram" },
            { "ang", "Nederlands-Antilliaanse gulde" },
            { "aoa", "Angolese kwanza" },
            { "ars", "Argentynse peso" },
            { "aud", "Australiese dollar" },
            { "awg", "Arubaanse floryn" },
            { "azn", "Azerbeidjaanse manat" },
            { "bam", "Bosnies-Herzegowiniese omskakelbare marka" },
            { "bbd", "Barbados-dollar" },
            { "bdt", "Bangladesjiese taka" },
            { "bgn", "Bulgaarse lev" },
            { "bhd", "Bahreinse dinar" },
            { "bif", "Burundiese frank" },
            { "bmd", "Bermuda-dollar" },
            { "bnd", "Broeneise dollar" },
            { "bob", "Boliviaanse boliviano" },
            { "brl", "Brasilliaanse reaal" },
            { "bsd", "Bahamiaanse dollar" },
            { "btn", "Bhoetanese ngoeltroem" },
            { "bwp", "Botswana-pula" },
            { "byn", "Belarusiese roebel" },
            { "byr", "Belo-Russiese roebel (2000\u20132016)" },
            { "bzd", "Beliziese dollar" },
            { "cad", "Kanadese dollar" },
            { "cdf", "Kongolese frank" },
            { "chf", "Switserse frank" },
            { "clp", "Chileense peso" },
            { "cnh", "Chinese joean (buiteland)" },
            { "cny", "Chinese joean" },
            { "cop", "Colombiaanse peso" },
            { "crc", "Costa Ricaanse col\u00f3n" },
            { "cuc", "Kubaanse omskakelbare peso" },
            { "cup", "Kubaanse peso" },
            { "cve", "Kaap Verdiese escudo" },
            { "czk", "Tsjeggiese kroon" },
            { "djf", "Djiboeti-frank" },
            { "dkk", "Deense kroon" },
            { "dop", "Dominikaanse peso" },
            { "dzd", "Algeriese dinar" },
            { "egp", "Egiptiese pond" },
            { "ern", "Eritrese nakfa" },
            { "etb", "Etiopiese birr" },
            { "eur", "Euro" },
            { "fjd", "Fidjiaanse dollar" },
            { "fkp", "Falkland-eilandse pond" },
            { "gbp", "Britse pond" },
            { "gel", "Georgiese lari" },
            { "ghc", "Ghanese cedi (1979\u20132007)" },
            { "ghs", "Ghanese cedi" },
            { "gip", "Gibraltarese pond" },
            { "gmd", "Gambiese dalasi" },
            { "gnf", "Guinese frank" },
            { "gns", "Guinese syli" },
            { "gtq", "Guatemalaanse kwetsal" },
            { "gyd", "Guyanese dollar" },
            { "hkd", "Hongkongse dollar" },
            { "hnl", "Hondurese lempira" },
            { "hrk", "Kroatiese kuna" },
            { "htg", "Ha\u00eftiaanse gourde" },
            { "huf", "Hongaarse florint" },
            { "idr", "Indonesiese roepia" },
            { "ils", "Israeliese nuwe sikkel" },
            { "inr", "Indiese roepee" },
            { "iqd", "Irakse dinar" },
            { "irr", "Iranse rial" },
            { "isk", "Yslandse kroon" },
            { "itl", "Italiaanse lier" },
            { "jmd", "Jamaikaanse dollar" },
            { "jod", "Jordaniese dinar" },
            { "jpy", "Japannese jen" },
            { "kes", "Keniaanse sjieling" },
            { "kgs", "Kirgisiese som" },
            { "khr", "Kambodjaanse riel" },
            { "kmf", "Comoraanse frank" },
            { "kpw", "Noord-Koreaanse won" },
            { "krw", "Suid-Koreaanse won" },
            { "kwd", "Koeweitse dinar" },
            { "kyd", "Cayman-eilandse dollar" },
            { "kzt", "Kazakse tenge" },
            { "lak", "Laosiaanse kip" },
            { "lbp", "Libanese pond" },
            { "lkr", "Sri Lankaanse roepee" },
            { "lrd", "Liberiese dollar" },
            { "lsl", "Lesotho loti" },
            { "ltl", "Litause litas" },
            { "lvl", "Lettiese lats" },
            { "lyd", "Libiese dinar" },
            { "mad", "Marokkaanse dirham" },
            { "mdl", "Moldowiese leu" },
            { "mga", "Malgassiese ariary" },
            { "mkd", "Macedoniese denar" },
            { "mmk", "Mianmese kyat" },
            { "mnt", "Mongoolse toegrik" },
            { "mop", "Macaose pataca" },
            { "mro", "Mauritaniese ouguiya (1973\u20132017)" },
            { "mru", "Mauritaniese ouguiya" },
            { "mur", "Mauritiaanse roepee" },
            { "mvr", "Malediviese rufia" },
            { "mwk", "Malawiese kwacha" },
            { "mxn", "Meksikaanse peso" },
            { "myr", "Maleisiese ringgit" },
            { "mzm", "Mosambiekse metical (1980\u20132006)" },
            { "mzn", "Mosambiekse metical" },
            { "nad", "Namibiese dollar" },
            { "ngn", "Nigeriese naira" },
            { "nio", "Nicaraguaanse c\u00f3rdoba" },
            { "nok", "Noorse kroon" },
            { "npr", "Nepalese roepee" },
            { "nzd", "Nieu-Seelandse dollar" },
            { "omr", "Omaanse rial" },
            { "pab", "Panamese balboa" },
            { "pen", "Peruaanse sol" },
            { "pgk", "Papoea-Nieu-Guinese kina" },
            { "php", "Filippynse peso" },
            { "pkr", "Pakistanse roepee" },
            { "pln", "Poolse zloty" },
            { "pyg", "Paraguaanse guarani" },
            { "qar", "Katarrese rial" },
            { "ron", "Roemeense leu" },
            { "rsd", "Serwiese dinar" },
            { "rub", "Russiese roebel" },
            { "rwf", "Rwandese frank" },
            { "sar", "Saoedi-Arabiese riyal" },
            { "sbd", "Salomonseilandse dollar" },
            { "scr", "Seychellese roepee" },
            { "sdg", "Soedannese pond" },
            { "sdp", "Soedannese pond (1957\u20131998)" },
            { "sek", "Sweedse kroon" },
            { "sgd", "Singapoer-dollar" },
            { "shp", "Sint Helena-pond" },
            { "sle", "Sierra Leoniese leone" },
            { "sll", "Sierra Leoniese leone (1964\u20142022)" },
            { "sos", "Somaliese sjieling" },
            { "srd", "Surinaamse dollar" },
            { "ssp", "Suid-Soedanese pond" },
            { "std", "S\u00e3o Tom\u00e9 en Pr\u00edncipe dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 en Pr\u00edncipe-dobra" },
            { "syp", "Siriese pond" },
            { "szl", "Swazilandse lilangeni" },
            { "thb", "Thaise baht" },
            { "tjs", "Tadjikse somoni" },
            { "tmt", "Turkmeense manat" },
            { "tnd", "Tunisiese dinar" },
            { "top", "Tongaanse pa\u2019anga" },
            { "trl", "Turkse lier (1922\u20132005)" },
            { "try", "Turkse lira" },
            { "ttd", "Trinidad en Tobago-dollar" },
            { "twd", "Nuwe Taiwanese dollar" },
            { "tzs", "Tanzaniese sjieling" },
            { "uah", "Oekra\u00efnse hriwna" },
            { "ugx", "Ugandese sjieling" },
            { "usd", "VSA-dollar" },
            { "uyu", "Uruguaanse peso" },
            { "uzs", "Oezbekiese som" },
            { "vef", "Venezolaanse bolivar" },
            { "ves", "Venezolaanse bol\u00edvar" },
            { "vnd", "Vi\u00ebtnamese dong" },
            { "vuv", "Vanuatuse vatu" },
            { "wst", "Samoaanse tala" },
            { "xaf", "Sentraal Afrikaanse CFA-frank" },
            { "xcd", "Oos-Karibiese dollar" },
            { "xof", "Wes-Afrikaanse CFA-frank" },
            { "xpf", "CFP-frank" },
            { "xxx", "Onbekende geldeenheid" },
            { "yer", "Jemenitiese rial" },
            { "zar", "Suid-Afrikaanse rand" },
            { "zmk", "Zambiese kwacha (1968\u20132012)" },
            { "zmw", "Zambiese kwacha" },
            { "zwd", "Zimbabwiese dollar" },
        };
        return data;
    }
}
